@@ -4,7 +4,7 @@ my $window    = new HTML::Window(\%parameter);
 $window->set_closeable(0);
 $window->set_moveable(0);
 $window->set_resizeable(0);
-print '<br/>';
+print br();
 print $window->windowHeader();
 print
   qq(<table align="center" border="0" cellpadding="0" cellspacing="0" summary="adminlayout" width="100%"><tr><td align="center"><a href="$ENV{SCRIPT_NAME}?action=settings">Settings</a>&#160;|&#160;<a href="$ENV{SCRIPT_NAME}?action=showTables">Database</a>&#160;|&#160;<a href="$ENV{SCRIPT_NAME}?action=editTreeview">Navigation</a>&#160;|&#160;<a href="$ENV{SCRIPT_NAME}?action=links&amp;dump=links">Links</a>&#160;|&#160;<a href="$ENV{SCRIPT_NAME}?action=showFiles">Files</a><br/><a href="$ENV{SCRIPT_NAME}?action=errorlog">Error Log</a>&#160;|&#160;<a href="$ENV{SCRIPT_NAME}?action=env">Envoirement Variables</a></td></tr></table><br>);
@@ -20,7 +20,7 @@ sub deleteExploit {
 sub showExploits {
         my @exploit = $database->fetch_AoH("select * from exploit");
 
-        print "<h3>Exploits</h3>";
+        print q(<div align="center" style="width:95%;overflow:auto;"><h3>Exploits</h3>);
         for(my $i = 0 ; $i <= $#exploit ; $i++) {
                 print "<hr/>";
                 foreach my $key (keys %{$exploit[$i]}) {
@@ -28,5 +28,5 @@ sub showExploits {
                 }
                 print qq(<a href="$ENV{SCRIPT_NAME}?action=deleteExploit&amp;id=$exploit[$i]->{id}">Delete</a>);
         }
-
+       print q(</div>);
 }
