@@ -8,17 +8,18 @@ $VAR1 = {
           'defaultAction' => 'news',
           'files' => {
                        'owner' => 'linse',
-                       'group' => 'users',
+                       'group' => 'wwwrun',
                        'chmod' => '0755'
                      },
           'size' => 22,
           'uploads' => {
                          'maxlength' => 2003153,
+                         'right' => 4,
                          'path' => '/srv/www//htdocs/downloads/',
                          'chmod' => 420,
                          'enabled' => 1
                        },
-          'floodtime' => 10,
+          'floodtime' => 5,
           'session' => '/srv/www/cgi-bin/config/session.pl',
           'scriptAlias' => 'cgi-bin',
           'admin' => {
@@ -29,14 +30,14 @@ $VAR1 = {
                        'town' => 'Berlin'
                      },
           'language' => 'en',
-          'version' => '0.33',
+          'version' => '0.34',
           'cgi' => {
                      'bin' => '/srv/www/cgi-bin',
                      'style' => 'Crystal',
                      'serverName' => 'localhost',
                      'cookiePath' => '/',
-                     'title' => 'Lindnerei',
-                     'mod_rewrite' => '1',
+                     'title' => 'CGI::CMS',
+                     'mod_rewrite' => 0,
                      'alias' => 'cgi-bin',
                      'DocumentRoot' => '/srv/www//htdocs',
                      'expires' => '+1y'
@@ -55,6 +56,7 @@ $VAR1 = {
           'config' => '/srv/www/cgi-bin/config/settings.pl',
           'news' => {
                       'maxlength' => 5000,
+                      'right' => 4,
                       'messages' => 10
                     }
         };
